@@ -89,8 +89,7 @@ def test_julia_sysimage():
     if "JULIA_SYSIMAGE_DIFFEQTORCH" in os.environ:
         assert Path(os.environ["JULIA_SYSIMAGE_DIFFEQTORCH"]).exists()
         test_pyjulia(
-            sysimage=os.environ["JULIA_SYSIMAGE_DIFFEQTORCH"],
-            call="using DifferentialEquations",
+            sysimage=os.environ["JULIA_SYSIMAGE_DIFFEQTORCH"]
         )
     else:
         log.debug("JULIA_SYSIMAGE_DIFFEQTORCH not set")
